@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::Get;
 
-our $DATE = '2016-06-23'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2016-06-26'; # DATE
+our $VERSION = '0.08'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -50,7 +50,7 @@ Bencher::Scenario::Accessors::Get - Benchmark attribute read/get
 
 =head1 VERSION
 
-This document describes version 0.07 of Bencher::Scenario::Accessors::Get (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-06-23.
+This document describes version 0.08 of Bencher::Scenario::Accessors::Get (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-06-26.
 
 =head1 SYNOPSIS
 
@@ -68,36 +68,86 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Perl::Examples::Accessors::Array> 0.05
+L<Perl::Examples::Accessors::Array> 0.06
 
-L<Perl::Examples::Accessors::ClassAccessor> 0.05
+L<Perl::Examples::Accessors::ClassAccessor> 0.06
 
-L<Perl::Examples::Accessors::ClassAccessorArray> 0.05
+L<Perl::Examples::Accessors::ClassAccessorArray> 0.06
 
-L<Perl::Examples::Accessors::ClassInsideOut> 0.05
+L<Perl::Examples::Accessors::ClassInsideOut> 0.06
 
-L<Perl::Examples::Accessors::ClassXSAccessor> 0.05
+L<Perl::Examples::Accessors::ClassXSAccessor> 0.06
 
-L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.05
+L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.06
 
-L<Perl::Examples::Accessors::Hash> 0.05
+L<Perl::Examples::Accessors::Hash> 0.06
 
-L<Perl::Examples::Accessors::Mo> 0.05
+L<Perl::Examples::Accessors::Mo> 0.06
 
-L<Perl::Examples::Accessors::MojoBase> 0.05
+L<Perl::Examples::Accessors::MojoBase> 0.06
 
-L<Perl::Examples::Accessors::Moo> 0.05
+L<Perl::Examples::Accessors::Moo> 0.06
 
-L<Perl::Examples::Accessors::Moose> 0.05
+L<Perl::Examples::Accessors::Moose> 0.06
 
-L<Perl::Examples::Accessors::Mouse> 0.05
+L<Perl::Examples::Accessors::Mouse> 0.06
 
-L<Perl::Examples::Accessors::ObjectSimple> 0.05
+L<Perl::Examples::Accessors::ObjectSimple> 0.06
+
+L<Perl::Examples::Accessors::SimpleAccessor> 0.06
 
 =head1 BENCHMARK PARTICIPANTS
 
 =over
 
+=item * Mo (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Mo->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Class::XSAccessor (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessor->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Class::InsideOut (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassInsideOut->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Simple::Accessor (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::SimpleAccessor->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Mouse (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Mouse->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Class::XSAccessor::Array (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessorArray->new; $o->attr1(42); $o }; $o->attr1
+
+
+
 =item * Moose (perl_code)
 
 Code template:
@@ -106,11 +156,19 @@ Code template:
 
 
 
-=item * Mo (perl_code)
+=item * no generator (hash-based) (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::Mo->new; $o->attr1(42); $o }; $o->attr1
+ state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Class::Accessor (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassAccessor->new; $o->attr1(42); $o }; $o->attr1
 
 
 
@@ -130,22 +188,6 @@ Code template:
 
 
 
-=item * Object::Simple (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ObjectSimple->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * no generator (hash-based) (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o->attr1(42); $o }; $o->attr1
-
-
-
 =item * Moo (perl_code)
 
 Code template:
@@ -154,38 +196,6 @@ Code template:
 
 
 
-=item * Class::InsideOut (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassInsideOut->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * Class::Accessor (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassAccessor->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * Class::XSAccessor::Array (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessorArray->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * Mouse (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Mouse->new; $o->attr1(42); $o }; $o->attr1
-
-
-
 =item * no generator (array-based) (perl_code)
 
 Code template:
@@ -194,11 +204,11 @@ Code template:
 
 
 
-=item * Class::XSAccessor (perl_code)
+=item * Object::Simple (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessor->new; $o->attr1(42); $o }; $o->attr1
+ state $o = do { my $o = Perl::Examples::Accessors::ObjectSimple->new; $o->attr1(42); $o }; $o->attr1
 
 
 
@@ -222,28 +232,29 @@ Code template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.1 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m Accessors::Get >>):
 
  +----------------------------+-----------+-----------+------------+---------+---------+
  | participant                | rate (/s) | time (ns) | vs_slowest |  errors | samples |
  +----------------------------+-----------+-----------+------------+---------+---------+
- | Class::Accessor            |   1610000 |       622 |       1    | 2.1e-10 |      23 |
- | Class::InsideOut           |   2170000 |       461 |       1.35 | 2.6e-10 |      20 |
- | Mojo::Base                 |   3300000 |       310 |       2    | 7.7e-10 |      25 |
- | Mo                         |   3500000 |       280 |       2.2  | 4.3e-10 |      24 |
- | Object::Simple             |   3700000 |       270 |       2.3  | 7.8e-10 |      29 |
- | no generator (hash-based)  |   3800000 |       260 |       2.4  | 4.2e-10 |      23 |
- | no generator (array-based) |   3900000 |       250 |       2.5  | 4.4e-10 |      31 |
- | Moose                      |   4300000 |       240 |       2.6  | 2.6e-10 |      20 |
- | Class::Accessor::Array     |   4460000 |       224 |       2.78 | 1.4e-10 |      20 |
- | Mouse                      |  10000000 |        96 |       6.5  | 9.9e-11 |      20 |
- | Class::XSAccessor          |  13000000 |        77 |       8.1  | 6.3e-10 |      23 |
- | Moo                        |  13000000 |        75 |       8.3  | 2.2e-10 |      20 |
- | Class::XSAccessor::Array   |  16000000 |        63 |       9.9  | 2.2e-10 |      35 |
- | raw hash access            |  22000000 |        46 |      14    | 4.4e-10 |      20 |
- | raw array access           |  35000000 |        28 |      22    | 1.5e-10 |      26 |
+ | Class::Accessor            |   2320000 |     431   |       1    |   2e-10 |      23 |
+ | Class::InsideOut           |   3640000 |     275   |       1.57 | 1.4e-10 |      20 |
+ | Simple::Accessor           |   3800000 |     270   |       1.6  | 4.9e-10 |      24 |
+ | no generator (hash-based)  |   5400000 |     180   |       2.3  | 4.2e-10 |      20 |
+ | Mo                         |   5400000 |     180   |       2.3  | 9.4e-10 |      20 |
+ | no generator (array-based) |   5500000 |     180   |       2.4  | 4.2e-10 |      20 |
+ | Mojo::Base                 |   5600000 |     180   |       2.4  | 3.1e-10 |      20 |
+ | Object::Simple             |   6010000 |     166.4 |       2.59 |   1e-11 |      20 |
+ | Moose                      |   6810000 |     147   |       2.93 | 4.5e-11 |      22 |
+ | Class::Accessor::Array     |   6960000 |     144   |       3    | 4.6e-11 |      20 |
+ | Mouse                      |  13200000 |      75.8 |       5.68 | 1.1e-11 |      20 |
+ | Class::XSAccessor          |  13300000 |      75.2 |       5.73 | 6.5e-11 |      21 |
+ | Moo                        |  14000000 |      71   |       6.1  | 1.6e-10 |      20 |
+ | Class::XSAccessor::Array   |  20000000 |      50   |       8.6  | 2.3e-10 |      20 |
+ | raw hash access            |  27000000 |      36   |      12    | 1.5e-10 |      20 |
+ | raw array access           |  39000000 |      25   |      17    | 2.1e-10 |      20 |
  +----------------------------+-----------+-----------+------------+---------+---------+
 
 =head1 DESCRIPTION
