@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::Set;
 
-our $DATE = '2016-06-23'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2016-06-26'; # DATE
+our $VERSION = '0.08'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -50,7 +50,7 @@ Bencher::Scenario::Accessors::Set - Benchmark attribute write/set
 
 =head1 VERSION
 
-This document describes version 0.07 of Bencher::Scenario::Accessors::Set (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-06-23.
+This document describes version 0.08 of Bencher::Scenario::Accessors::Set (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-06-26.
 
 =head1 SYNOPSIS
 
@@ -68,36 +68,86 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Perl::Examples::Accessors::Array> 0.05
+L<Perl::Examples::Accessors::Array> 0.06
 
-L<Perl::Examples::Accessors::ClassAccessor> 0.05
+L<Perl::Examples::Accessors::ClassAccessor> 0.06
 
-L<Perl::Examples::Accessors::ClassAccessorArray> 0.05
+L<Perl::Examples::Accessors::ClassAccessorArray> 0.06
 
-L<Perl::Examples::Accessors::ClassInsideOut> 0.05
+L<Perl::Examples::Accessors::ClassInsideOut> 0.06
 
-L<Perl::Examples::Accessors::ClassXSAccessor> 0.05
+L<Perl::Examples::Accessors::ClassXSAccessor> 0.06
 
-L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.05
+L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.06
 
-L<Perl::Examples::Accessors::Hash> 0.05
+L<Perl::Examples::Accessors::Hash> 0.06
 
-L<Perl::Examples::Accessors::Mo> 0.05
+L<Perl::Examples::Accessors::Mo> 0.06
 
-L<Perl::Examples::Accessors::MojoBase> 0.05
+L<Perl::Examples::Accessors::MojoBase> 0.06
 
-L<Perl::Examples::Accessors::Moo> 0.05
+L<Perl::Examples::Accessors::Moo> 0.06
 
-L<Perl::Examples::Accessors::Moose> 0.05
+L<Perl::Examples::Accessors::Moose> 0.06
 
-L<Perl::Examples::Accessors::Mouse> 0.05
+L<Perl::Examples::Accessors::Mouse> 0.06
 
-L<Perl::Examples::Accessors::ObjectSimple> 0.05
+L<Perl::Examples::Accessors::ObjectSimple> 0.06
+
+L<Perl::Examples::Accessors::SimpleAccessor> 0.06
 
 =head1 BENCHMARK PARTICIPANTS
 
 =over
 
+=item * Mo (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Mo->new; $o }; $o->attr1(42)
+
+
+
+=item * Class::XSAccessor (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessor->new; $o }; $o->attr1(42)
+
+
+
+=item * Class::InsideOut (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassInsideOut->new; $o }; $o->attr1(42)
+
+
+
+=item * Simple::Accessor (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::SimpleAccessor->new; $o }; $o->attr1(42)
+
+
+
+=item * Mouse (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Mouse->new; $o }; $o->attr1(42)
+
+
+
+=item * Class::XSAccessor::Array (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessorArray->new; $o }; $o->attr1(42)
+
+
+
 =item * Moose (perl_code)
 
 Code template:
@@ -106,11 +156,19 @@ Code template:
 
 
 
-=item * Mo (perl_code)
+=item * no generator (hash-based) (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::Mo->new; $o }; $o->attr1(42)
+ state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o }; $o->attr1(42)
+
+
+
+=item * Class::Accessor (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassAccessor->new; $o }; $o->attr1(42)
 
 
 
@@ -130,22 +188,6 @@ Code template:
 
 
 
-=item * Object::Simple (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ObjectSimple->new; $o }; $o->attr1(42)
-
-
-
-=item * no generator (hash-based) (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o }; $o->attr1(42)
-
-
-
 =item * Moo (perl_code)
 
 Code template:
@@ -154,38 +196,6 @@ Code template:
 
 
 
-=item * Class::InsideOut (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassInsideOut->new; $o }; $o->attr1(42)
-
-
-
-=item * Class::Accessor (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassAccessor->new; $o }; $o->attr1(42)
-
-
-
-=item * Class::XSAccessor::Array (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessorArray->new; $o }; $o->attr1(42)
-
-
-
-=item * Mouse (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Mouse->new; $o }; $o->attr1(42)
-
-
-
 =item * no generator (array-based) (perl_code)
 
 Code template:
@@ -194,11 +204,11 @@ Code template:
 
 
 
-=item * Class::XSAccessor (perl_code)
+=item * Object::Simple (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessor->new; $o }; $o->attr1(42)
+ state $o = do { my $o = Perl::Examples::Accessors::ObjectSimple->new; $o }; $o->attr1(42)
 
 
 
@@ -222,28 +232,29 @@ Code template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.1 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m Accessors::Set >>):
 
  +----------------------------+-----------+-----------+------------+---------+---------+
- | participant                | rate (/s) | time (ns) | vs_slowest |  errors | samples |
+ | participant                | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +----------------------------+-----------+-----------+------------+---------+---------+
- | Class::Accessor            |   1100000 |       950 |       1    | 1.7e-09 |      20 |
- | Class::InsideOut           |   1770000 |       564 |       1.68 | 2.9e-10 |      20 |
- | no generator (hash-based)  |   2800000 |       360 |       2.6  |   1e-09 |      20 |
- | Mojo::Base                 |   3010000 |       332 |       2.86 | 2.8e-10 |      20 |
- | no generator (array-based) |   3020000 |       332 |       2.86 |   1e-10 |      20 |
- | Object::Simple             |   3190000 |       313 |       3.03 | 1.9e-10 |      31 |
- | Moose                      |   3210000 |       311 |       3.05 | 2.1e-10 |      20 |
- | Mo                         |   3360000 |       298 |       3.19 |   9e-11 |      20 |
- | Class::Accessor::Array     |   3410000 |       294 |       3.23 | 1.5e-10 |      20 |
- | Mouse                      |   5460000 |       183 |       5.19 | 1.5e-10 |      24 |
- | Moo                        |   8000000 |       130 |       7.6  | 1.4e-10 |      26 |
- | Class::XSAccessor          |   8400000 |       120 |       7.9  | 1.5e-10 |      20 |
- | Class::XSAccessor::Array   |  10000000 |       100 |       9.5  | 2.1e-10 |      20 |
- | raw hash access            |  17000000 |        60 |      16    | 3.5e-10 |      20 |
- | raw array access           |  20000000 |        50 |      20    |   7e-10 |      33 |
+ | Simple::Accessor           |    326000 |  3.07     |     1      | 2.5e-09 |      20 |
+ | Class::Accessor            |   1825000 |  0.5478   |     5.601  | 1.1e-11 |      20 |
+ | Class::InsideOut           |   2840000 |  0.352    |     8.72   | 1.7e-10 |      33 |
+ | no generator (hash-based)  |   4370000 |  0.229    |    13.4    |   1e-10 |      21 |
+ | Moose                      |   4600000 |  0.22     |    14      | 4.2e-10 |      20 |
+ | no generator (array-based) |   4623130 |  0.216304 |    14.1865 |   0     |      24 |
+ | Mo                         |   4720000 |  0.212    |    14.5    |   1e-10 |      22 |
+ | Mojo::Base                 |   5020000 |  0.199    |    15.4    | 9.5e-11 |      24 |
+ | Class::Accessor::Array     |   5400000 |  0.19     |    16      | 4.2e-10 |      20 |
+ | Object::Simple             |   5410000 |  0.185    |    16.6    |   1e-10 |      20 |
+ | Mouse                      |  10400000 |  0.0958   |    32      | 7.1e-11 |      24 |
+ | Class::XSAccessor          |  11000000 |  0.093    |    33      | 2.1e-10 |      20 |
+ | Moo                        |  10900000 |  0.0919   |    33.4    | 4.7e-11 |      35 |
+ | Class::XSAccessor::Array   |  12200000 |  0.0817   |    37.5    | 5.2e-11 |      21 |
+ | raw hash access            |  20500000 |  0.0489   |    62.8    | 1.2e-11 |      21 |
+ | raw array access           |  29300000 |  0.0341   |    90      | 1.2e-11 |      23 |
  +----------------------------+-----------+-----------+------------+---------+---------+
 
 =head1 DESCRIPTION
